==> koffice-1.9.98.3.tar.bz2: koffice-1.9.98.3/krita/main.cc <==
/*
 *  main.cc - part of KImageShop
 *
 *  Copyright (c) 1999 Matthias Elter <me@kde.org>
 *  Copyright (c) 2002 Patrick Julien <freak@codepimps.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 */

#include <kcmdlineargs.h>
#include <KoApplication.h>
#include <krita_export.h>
#include <stdlib.h>
#include <stdio.h>
#include <kis_debug.h>
#include <QString>

#include "ui/kis_aboutdata.h"

#ifndef NDEBUG
static void qtMessageHandler(QtMsgType type, const char *msg)
{
    fprintf(stderr, "%s\n", msg);
    if (type == QtFatalMsg)
        abort();
}
#endif

extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
{
#ifndef NDEBUG
    qInstallMsgHandler(qtMessageHandler);
#endif
    KCmdLineArgs::init(argc, argv, newKritaAboutData());

    KCmdLineOptions options;
    options.add("+[file(s)]", ki18n("File(s) or URL(s) to open"));
    KCmdLineArgs::addCmdLineOptions(options);

    KoApplication app;

    if (!app.start())
        return 1;

    return app.exec();
}

==> koffice-1.9.98.7.tar.bz2: koffice-1.9.98.7/krita/main.cc <==
/*
 *  main.cc - part of KImageShop
 *
 *  Copyright (c) 1999 Matthias Elter <me@kde.org>
 *  Copyright (c) 2002 Patrick Julien <freak@codepimps.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 */

#include <kcmdlineargs.h>
#include <KoApplication.h>
#include <krita_export.h>
#include <stdlib.h>
#include <stdio.h>
#include <kis_debug.h>
#include <QString>

#include "ui/kis_aboutdata.h"

#ifndef NDEBUG
static void qtMessageHandler(QtMsgType type, const char *msg)
{
    fprintf(stderr, "%s\n", msg);
    if (type == QtFatalMsg)
        abort();
}
#endif

extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
{
    int state;
    KAboutData * aboutData=newKritaAboutData();

#ifndef NDEBUG
    qInstallMsgHandler(qtMessageHandler);
#endif
    KCmdLineArgs::init(argc, argv, aboutData);

    KCmdLineOptions options;
    options.add("+[file(s)]", ki18n("File(s) or URL(s) to open"));
    KCmdLineArgs::addCmdLineOptions(options);

    KoApplication app;

    if (!app.start())
        return 1;

    state=app.exec();

    delete (aboutData);

    return state;
}
